@@ -174,7 +174,7 @@ def upload_ota_payload(ctx: MemfaultCliClickContext, path: str, **kwargs):
 
 def main():
     logging.basicConfig(level=logging.INFO, format="%(levelname)s: %(message)s")
-    cli()
+    cli(auto_envvar_prefix="MEMFAULT")
 
 
 if __name__ == "__main__":
