@@ -70,6 +70,9 @@ class Uploader:
     def _projects_base_url(self) -> str:
         return f"{self.base_url}/api/v0/organizations/{self.ctx.org}/projects/{self.ctx.project}"
 
+    def _projects_ui_base_url(self) -> str:
+        return f"{self.base_url}/organizations/{self.ctx.org}/projects/{self.ctx.project}"
+
     def upload_url(self) -> str:
         """
         The upload URL for a 'prepared upload' for the configured authentication method.
@@ -89,6 +92,10 @@ class Uploader:
         """The final URL to POST to during the prepared upload sequence."""
         pass
 
+    def ui_url(self) -> Optional[str]:
+        """The UI URL at which results from the operation can be seen"""
+        return None
+
     @abstractmethod
     def requests_auth_params(self) -> dict:
         """A dict of `requests` parameters that should be used for authentication."""
@@ -152,6 +159,8 @@ class Uploader:
         self._put_file(upload_url, progressbar=progressbar)
         self._post_token(token)
         LOG.info(f"{self.file_path}: uploaded!")
+        if self.ui_url:
+            click.echo(f"You can view in the UI here:\n   {self.ui_url()}")
         return True
 
 
@@ -272,6 +281,10 @@ class ReleaseArtifactUploader(Uploader):
     def entity_url(self) -> str:
         return f"{self._projects_base_url()}/releases/ota_payload"
 
+    def ui_url(self) -> str:
+        _, software_version = self.ctx.software_info
+        return f"{self._projects_ui_base_url()}/releases/{software_version}"
+
     def post_token_extra_request_data(self) -> Optional[Dict]:
         software_type, software_version = self.ctx.software_info
         return {
@@ -311,7 +324,9 @@ class DirectoryUploader(Uploader):
         # We should generalize this logic into a class or have a function called `get_uploaders`
         # that the calling client can then parallelize by calling `.upload()` on each.
         with ThreadPoolExecutor(max_workers=self.ctx.concurrency) as pool:
-            pool.map(do_upload, queued_uploaders)
+            # NB: We need to read the result for exceptions to be raised
+            for result in pool.map(do_upload, queued_uploaders):
+                pass
 
         return did_upload
 
